@@ -10,6 +10,14 @@ use crate::{OrderBookMsg, TradeMsg};
 
 use serde_json::Result;
 
+pub(crate) fn extract_symbol(market_type: MarketType, msg: &str) -> Option<String> {
+    if market_type == MarketType::Spot {
+        gate_spot::extract_symbol(msg)
+    } else {
+        gate_swap::extract_symbol(market_type, msg)
+    }
+}
+
 pub(crate) fn parse_trade(market_type: MarketType, msg: &str) -> Result<Vec<TradeMsg>> {
     if market_type == MarketType::Spot {
         gate_spot::parse_trade(msg)
